@@ -11,6 +11,7 @@ from rich.prompt import Prompt
 
 from flexlate.add_mode import AddMode, get_expanded_out_root
 from flexlate.branch_update import modify_files_via_branches_and_temp_repo
+from flexlate.config import TemplateSource
 from flexlate.config_manager import (
     ConfigManager,
     determine_config_path_from_roots_and_add_mode,
@@ -26,6 +27,7 @@ from flexlate.path_ops import (
 )
 from flexlate.render.multi import MultiRenderer
 from flexlate.styles import SUCCESS_STYLE, INFO_STYLE, console, styled, print_styled
+from flexlate.syncer import Syncer
 from flexlate.template.base import Template
 from flexlate.template_data import TemplateData
 from flexlate.transactions.transaction import (
@@ -161,8 +163,13 @@ class Adder:
             out_root, project_root, template.render_relative_root_in_output, add_mode
         )
 
+        # Get path it is being rendered at to display to user
+        render_path = expanded_out_root
+        if not expanded_out_root.is_absolute():
+            render_path = (project_root / expanded_out_root).resolve()
+
         print_styled(
-            f"Applying template {template.name} to {expanded_out_root.resolve()}",
+            f"Applying template {template.name} to {render_path}",
             INFO_STYLE,
         )
 
@@ -228,7 +235,7 @@ class Adder:
             config_manager=config_manager,
         )
         print_styled(
-            f"Successfully applied template {template.name} to {expanded_out_root.resolve()}",
+            f"Successfully applied template {template.name} to {render_path}",
             SUCCESS_STYLE,
         )
 
@@ -309,10 +316,27 @@ class Adder:
         config_manager: ConfigManager = ConfigManager(),
         updater: Updater = Updater(),
         renderer: MultiRenderer = MultiRenderer(),
-    ):
+        syncer: Syncer = Syncer(),
+    ) -> str:
         with tempfile.TemporaryDirectory() as temp_dir:
             temp_path = Path(temp_dir)
+
             repo = Repo.init(temp_dir)
+
+            def sync():
+                syncer.sync_local_changes_to_flexlate_branches(
+                    repo,
+                    transaction,
+                    merged_branch_name=merged_branch_name,
+                    base_merged_branch_name=merged_branch_name,
+                    template_branch_name=template_branch_name,
+                    base_template_branch_name=template_branch_name,
+                    no_input=True,
+                    updater=updater,
+                    renderer=renderer,
+                    config_manager=config_manager,
+                )
+
             temp_file = temp_path / "README.md"
             temp_file.touch()
             stage_and_commit_all(repo, "Initial commit")
@@ -405,9 +429,38 @@ class Adder:
                 stage_and_commit_all(
                     repo, "Move flexlate config and remove temporary file"
                 )
+                sync()
 
             final_out_path = path / folder_name
             shutil.copytree(output_folder, final_out_path)
+            repo = Repo(final_out_path)
+
+            # Now update template source path that was previously relative to temp directory
+            if template.git_url is None and not Path(template.path).is_absolute():
+                cwd = Path(os.getcwd())
+
+                def move_source_path_to_be_relative_to_destination(
+                    source: TemplateSource,
+                ):
+                    source.path = str(
+                        os.path.relpath(
+                            (cwd / Path(template.template_source_path)).resolve(),
+                            final_out_path,
+                        )
+                    )
+
+                config_manager.update_template_sources(
+                    [template.name],
+                    move_source_path_to_be_relative_to_destination,
+                    project_root=final_out_path,
+                )
+                stage_and_commit_all(
+                    repo,
+                    "Move template source path to match permanent destination of project",
+                )
+                sync()
+
+            return folder_name
 
 
 def _add_template_commit_message(
