@@ -601,14 +601,17 @@ def test_init_project_from_template_source_path_remote_cookiecutter(
 
     adder = Adder()
     with change_directory_to(GENERATED_FILES_DIR):
-        adder.init_project_from_template_source_path(
+        folder_name = adder.init_project_from_template_source_path(
             template, transaction, no_input=True
         )
 
-    project_dir = GENERATED_FILES_DIR / "abc"
+    project_dir = GENERATED_FILES_DIR / folder_name
     # Ensure project is a git repo
     repo = Repo(project_dir)
-    assert repo.commit().message == "Move flexlate config and remove temporary file\n"
+    assert (
+        repo.commit().message
+        == "Merge branch 'flexlate-templates' into flexlate-output\n"
+    )
 
     content_path = project_dir / "abc.txt"
     content = content_path.read_text()
@@ -645,11 +648,37 @@ def test_init_project_from_template_source_path_local_copier(
 
     adder = Adder()
     with change_directory_to(GENERATED_FILES_DIR):
-        adder.init_project_from_template_source_path(
+        folder_name = adder.init_project_from_template_source_path(
             template, transaction, no_input=True
         )
 
-    project_dir = GENERATED_FILES_DIR / "project"
+    project_dir = GENERATED_FILES_DIR / folder_name
+
+    _assert_init_from_local_copier_output_correct(project_dir, template)
+
+
+def test_init_project_from_template_source_path_local_copier_in_another_directory(
+    copier_one_template: CopierTemplate,
+    add_source_and_output_transaction: FlexlateTransaction,
+):
+    template = copier_one_template
+    transaction = add_source_and_output_transaction
+
+    adder = Adder()
+    with change_directory_to(GENERATED_FILES_DIR):
+        subdir = GENERATED_FILES_DIR / "subdir"
+        folder_name = adder.init_project_from_template_source_path(
+            template, transaction, path=subdir, no_input=True
+        )
+
+    project_dir = subdir / folder_name
+
+    _assert_init_from_local_copier_output_correct(project_dir, template)
+
+
+def _assert_init_from_local_copier_output_correct(
+    project_dir: Path, template: Template
+):
     # Ensure project is a git repo
     repo = Repo(project_dir)
     assert_main_commit_message_matches(
